@@ -1,7 +1,9 @@
 from vortex.handler.TupleActionProcessor import TupleActionProcessor
 
 from peek_plugin_docdb_generic_menu._private.PluginNames import docDbGenericMenuFilt
-from peek_plugin_docdb_generic_menu._private.PluginNames import docDbGenericMenuActionProcessorName
+from peek_plugin_docdb_generic_menu._private.PluginNames import (
+    docDbGenericMenuActionProcessorName,
+)
 from .controller.MainController import MainController
 
 
@@ -9,5 +11,6 @@ def makeTupleActionProcessorHandler(mainController: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=docDbGenericMenuActionProcessorName,
         additionalFilt=docDbGenericMenuFilt,
-        defaultDelegate=mainController)
+        defaultDelegate=mainController,
+    )
     return processor
